<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="tr">
<context>
    <name>AboutDialog</name>
    <message>
        <location filename="../aboutdialog.cpp" line="27"/>
        <source>About</source>
        <translation>Hakkında</translation>
    </message>
    <message>
        <location filename="../aboutdialog.cpp" line="30"/>
        <source>Launch application with image file path as argument to load the file.</source>
        <translation>Dosyayı yüklemek için değişken olarak resim dosyası yolu ile uygulamayı çalıştır.</translation>
    </message>
    <message>
        <location filename="../aboutdialog.cpp" line="31"/>
        <source>Drag and drop image file onto the window is also supported.</source>
        <translation>Pencere üzerine resim dosyası sürükle bırak ta destekleniyor.</translation>
    </message>
    <message>
        <location filename="../aboutdialog.cpp" line="32"/>
        <source>None of the operations in this application will alter the pictures on disk.</source>
        <translation>Bu uygulamadaki işlemlerin hiçbiri diskteki resimleri değiştirmeyecektir.</translation>
    </message>
    <message>
        <location filename="../aboutdialog.cpp" line="33"/>
        <source>Context menu option explanation:</source>
        <translation>İçerik menüsü seçeneği açıklaması:</translation>
    </message>
    <message>
        <location filename="../aboutdialog.cpp" line="40"/>
        <source>Make window stay on top of all other windows.</source>
        <translation>Pencereyi diğer tüm pencerelerin üzerinde tut.</translation>
    </message>
    <message>
        <location filename="../aboutdialog.cpp" line="43"/>
        <source>Avoid close window accidentally. (eg. by double clicking the window)</source>
        <translation>Pencereyi yanlışlıkla kapatmaktan kaçın. (örn. pencereye çift tıklayarak)</translation>
    </message>
    <message>
        <location filename="../aboutdialog.cpp" line="51"/>
        <source>Version: %1</source>
        <translation>Sürüm: %1</translation>
    </message>
    <message>
        <source>Copyright (c) 2020 %1</source>
        <translation type="vanished">Telif hakkı (c) 2020 %1</translation>
    </message>
    <message>
        <location filename="../aboutdialog.cpp" line="57"/>
        <source>Logo designed by %1</source>
        <translation>Logo tasarımcısı: %1</translation>
    </message>
    <message>
        <location filename="../aboutdialog.cpp" line="59"/>
        <source>Built with Qt %1 (%2)</source>
        <translation>Qt %1 (%2) ile inşa edilmiştir</translation>
    </message>
    <message>
        <location filename="../aboutdialog.cpp" line="60"/>
        <source>Source code</source>
        <translation>Kaynak kodu</translation>
    </message>
    <message>
        <location filename="../aboutdialog.cpp" line="70"/>
        <source>Contributors</source>
        <translation>Katkıda bulunanlar</translation>
    </message>
    <message>
        <location filename="../aboutdialog.cpp" line="72"/>
        <source>List of contributors on GitHub</source>
        <translation>Github üzerindeki katkı sağlayıcıların listesi</translation>
    </message>
    <message>
        <location filename="../aboutdialog.cpp" line="73"/>
        <source>Thanks to all people who contributed to this project.</source>
        <translation>Bu projeye katkı sağlayan herkese teşekkürler.</translation>
    </message>
    <message>
        <location filename="../aboutdialog.cpp" line="77"/>
        <source>Translators</source>
        <translation>Çevirmenler</translation>
    </message>
    <message>
        <location filename="../aboutdialog.cpp" line="78"/>
        <source>I would like to thank the following people who volunteered to translate this application.</source>
        <translation>Bu uygulamayı çevirmeye gönüllü olan aşağıdaki kişilere teşekkür etmek istiyorum.</translation>
    </message>
    <message>
        <location filename="../aboutdialog.cpp" line="122"/>
        <source>%1 is built on the following free software libraries:</source>
        <comment>Free as in freedom</comment>
        <translation>%1 aşağıdaki özgür yazılım kitaplıkları üzerinde inşa edilmiştir:</translation>
    </message>
    <message>
        <location filename="../aboutdialog.cpp" line="146"/>
        <source>&amp;Special Thanks</source>
        <translation>Özel %Teşekkürler</translation>
    </message>
    <message>
        <location filename="../aboutdialog.cpp" line="148"/>
        <source>&amp;Third-party Libraries</source>
        <translation>Üçüncü Par&amp;ti Kitaplıklar</translation>
    </message>
    <message>
        <location filename="../aboutdialog.cpp" line="84"/>
        <source>Your Rights</source>
        <translation>Haklarınız</translation>
    </message>
    <message>
        <location filename="../aboutdialog.cpp" line="54"/>
        <source>Copyright (c) %1 %2</source>
        <comment>%1 is year, %2 is the name of copyright holder(s)</comment>
        <translation>Telif Hakkı (c) %1 %2</translation>
    </message>
    <message>
        <location filename="../aboutdialog.cpp" line="86"/>
        <source>%1 is released under the MIT License.</source>
        <translation>%1, MIT Lisansı altında sunulmuştur.</translation>
    </message>
    <message>
        <location filename="../aboutdialog.cpp" line="87"/>
        <source>This license grants people a number of freedoms:</source>
        <translation>Bu lisans birkaç özgürlüğü kişilere veriyor:</translation>
    </message>
    <message>
        <location filename="../aboutdialog.cpp" line="88"/>
        <source>You are free to use %1, for any purpose</source>
        <translation>%1&apos;i herhangi bir amaç için kullanmakta özgürsünüz</translation>
    </message>
    <message>
        <location filename="../aboutdialog.cpp" line="89"/>
        <source>You are free to distribute %1</source>
        <translation>%1&apos;i dağıtmakta özgürsünüz</translation>
    </message>
    <message>
        <location filename="../aboutdialog.cpp" line="90"/>
        <source>You can study how %1 works and change it</source>
        <translation>%1&apos;in nasıl çalıştığıyla ilgili çalışabilir ve onu değiştirebilirsiniz</translation>
    </message>
    <message>
        <location filename="../aboutdialog.cpp" line="91"/>
        <source>You can distribute changed versions of %1</source>
        <translation>%1&apos;in değiştirilmiş sürümünü dağıtabilirsiniz</translation>
    </message>
    <message>
        <location filename="../aboutdialog.cpp" line="93"/>
        <source>The MIT license guarantees you this freedom. Nobody is ever permitted to take it away.</source>
        <translation>MIT lisansı özgürlüğünüzü garanti eder. Hiç kimsenin özgürlüğünüzü sizden almasına bile izin verilmez.</translation>
    </message>
    <message>
        <location filename="../aboutdialog.cpp" line="121"/>
        <source>Third-party Libraries used by %1</source>
        <translation>%1 tarafından kullanılan Üçüncü Parti Kitaplıklar</translation>
    </message>
    <message>
        <location filename="../aboutdialog.cpp" line="144"/>
        <source>&amp;Help</source>
        <translation>&amp;Yardım</translation>
    </message>
    <message>
        <location filename="../aboutdialog.cpp" line="145"/>
        <source>&amp;About</source>
        <translation>H&amp;akkında</translation>
    </message>
    <message>
        <location filename="../aboutdialog.cpp" line="147"/>
        <source>&amp;License</source>
        <translation>&amp;Lisans</translation>
    </message>
</context>
<context>
    <name>GraphicsScene</name>
    <message>
        <location filename="../graphicsscene.cpp" line="90"/>
        <source>Drag image here</source>
        <translation>Resmi buraya sürükleyin</translation>
    </message>
</context>
<context>
    <name>GraphicsView</name>
    <message>
        <location filename="../graphicsview.cpp" line="338"/>
        <source>File url list is empty</source>
        <translation>Dosya URL listesi boş</translation>
    </message>
    <message>
        <location filename="../graphicsview.cpp" line="56"/>
        <source>File is not a valid image</source>
        <translation>Dosya, geçerli bir resim değil</translation>
    </message>
    <message>
        <location filename="../graphicsview.cpp" line="61"/>
        <location filename="../graphicsview.cpp" line="66"/>
        <source>Image data is invalid or currently unsupported</source>
        <translation>Resim verisi geçersiz veya şuan desteklenmiyor</translation>
    </message>
    <message>
        <location filename="../graphicsview.cpp" line="346"/>
        <source>Image data is invalid</source>
        <translation>Resim verisi geçersiz</translation>
    </message>
    <message>
        <location filename="../graphicsview.cpp" line="353"/>
        <source>Not supported mimedata: %1</source>
        <translation>Desteklenmeyen dosya türü verisi: %1</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../mainwindow.cpp" line="170"/>
        <source>File url list is empty</source>
        <translation>Dosya URL listesi boş</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="413"/>
        <source>&amp;Copy</source>
        <translation>&amp;Kopyala</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="102"/>
        <source>Copy P&amp;ixmap</source>
        <translation>P&amp;ixmap&apos;i Kopyala</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="103"/>
        <source>Copy &amp;File Path</source>
        <translation>&amp;Dosya Yolunu Kopyala</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="119"/>
        <source>Properties</source>
        <translation>Özellikler</translation>
    </message>
    <message>
        <location filename="../aboutdialog.cpp" line="39"/>
        <location filename="../actionmanager.cpp" line="105"/>
        <source>Stay on top</source>
        <translation>Üstte tut</translation>
    </message>
    <message>
        <location filename="../aboutdialog.cpp" line="42"/>
        <location filename="../actionmanager.cpp" line="106"/>
        <source>Protected mode</source>
        <translation>Korumalı kip</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="91"/>
        <source>Zoom in</source>
        <translation>Yaklaştır</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="92"/>
        <source>Zoom out</source>
        <translation>Uzaklaştır</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="99"/>
        <source>Flip &amp;Horizontally</source>
        <translation>&amp;Yatay Çevir</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="104"/>
        <source>&amp;Paste</source>
        <translation>Ya&amp;pıştır</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="93"/>
        <source>Toggle Checkerboard</source>
        <translation>Damalı Ekrana Geç</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="87"/>
        <source>&amp;Open...</source>
        <translation>&amp;Aç...</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="89"/>
        <source>Actual size</source>
        <translation>Gerçek boyut</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="90"/>
        <source>Toggle maximize</source>
        <translation>Tam boyuta geç</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="94"/>
        <source>Rotate right</source>
        <translation>Sağa döndür</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="96"/>
        <source>Previous image</source>
        <translation>Önceki resim</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="97"/>
        <source>Next image</source>
        <translation>Sonraki resim</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="107"/>
        <source>Configure...</source>
        <translation>Yapılandır...</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="108"/>
        <source>Help</source>
        <translation>Yardım</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="111"/>
        <source>Show in File Explorer</source>
        <comment>File Explorer is the name of explorer.exe under Windows</comment>
        <translation>Dosya Gezgini&apos;nde Göster</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="117"/>
        <source>Show in directory</source>
        <translation>Dizinde göster</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="120"/>
        <source>Quit</source>
        <translation>Çıkış</translation>
    </message>
</context>
<context>
    <name>MetadataDialog</name>
    <message>
        <location filename="../metadatadialog.cpp" line="84"/>
        <source>Image Metadata</source>
        <translation>Resim Üstverisi</translation>
    </message>
</context>
<context>
    <name>MetadataModel</name>
    <message>
        <location filename="../metadatamodel.cpp" line="41"/>
        <source>Origin</source>
        <comment>Section name.</comment>
        <translation>Köken</translation>
    </message>
    <message>
        <location filename="../metadatamodel.cpp" line="42"/>
        <source>Image</source>
        <comment>Section name.</comment>
        <translation>Resim</translation>
    </message>
    <message>
        <location filename="../metadatamodel.cpp" line="46"/>
        <source>File</source>
        <comment>Section name.</comment>
        <translation>Dosya</translation>
    </message>
    <message>
        <location filename="../metadatamodel.cpp" line="43"/>
        <source>Camera</source>
        <comment>Section name.</comment>
        <translation>Kamera</translation>
    </message>
    <message>
        <location filename="../metadatamodel.cpp" line="33"/>
        <source>%1 File</source>
        <translation>%1 Dosya</translation>
    </message>
    <message>
        <location filename="../metadatamodel.cpp" line="40"/>
        <source>Description</source>
        <comment>Section name.</comment>
        <translation>Açıklama</translation>
    </message>
    <message>
        <location filename="../metadatamodel.cpp" line="44"/>
        <source>Advanced photo</source>
        <comment>Section name.</comment>
        <translation>Gelişmiş foto</translation>
    </message>
    <message>
        <location filename="../metadatamodel.cpp" line="45"/>
        <source>GPS</source>
        <comment>Section name.</comment>
        <translation>GPS</translation>
    </message>
    <message>
        <location filename="../metadatamodel.cpp" line="50"/>
        <source>Dimensions</source>
        <translation>Boyutlar</translation>
    </message>
    <message>
        <location filename="../metadatamodel.cpp" line="52"/>
        <source>Aspect ratio</source>
        <translation>En boy oranı</translation>
    </message>
    <message>
        <location filename="../metadatamodel.cpp" line="56"/>
        <source>Frame count</source>
        <translation>Kare sayısı</translation>
    </message>
    <message>
        <location filename="../metadatamodel.cpp" line="60"/>
        <source>Name</source>
        <translation>Adı</translation>
    </message>
    <message>
        <location filename="../metadatamodel.cpp" line="62"/>
        <source>Item type</source>
        <translation>Öge türü</translation>
    </message>
    <message>
        <location filename="../metadatamodel.cpp" line="64"/>
        <source>Folder path</source>
        <translation>Klasör yolu</translation>
    </message>
    <message>
        <location filename="../metadatamodel.cpp" line="66"/>
        <source>Size</source>
        <translation>Boyut</translation>
    </message>
    <message>
        <location filename="../metadatamodel.cpp" line="68"/>
        <source>Date created</source>
        <translation>Oluşturulma tarihi</translation>
    </message>
    <message>
        <location filename="../metadatamodel.cpp" line="70"/>
        <source>Date modified</source>
        <translation>Değiştirilme tarihi</translation>
    </message>
    <message>
        <location filename="../metadatamodel.cpp" line="77"/>
        <source>Title</source>
        <translation>Başlık</translation>
    </message>
    <message>
        <location filename="../metadatamodel.cpp" line="79"/>
        <source>Subject</source>
        <translation>Konu</translation>
    </message>
    <message>
        <location filename="../metadatamodel.cpp" line="81"/>
        <source>Rating</source>
        <translation>Değerlendirme</translation>
    </message>
    <message>
        <location filename="../metadatamodel.cpp" line="83"/>
        <source>Tags</source>
        <translation>Etiketler</translation>
    </message>
    <message>
        <location filename="../metadatamodel.cpp" line="85"/>
        <source>Comments</source>
        <translation>Yorumlar</translation>
    </message>
    <message>
        <location filename="../metadatamodel.cpp" line="88"/>
        <source>Authors</source>
        <translation>Sanatçılar</translation>
    </message>
    <message>
        <location filename="../metadatamodel.cpp" line="90"/>
        <source>Date taken</source>
        <translation>Çekilme tarihi</translation>
    </message>
    <message>
        <location filename="../metadatamodel.cpp" line="96"/>
        <source>Program name</source>
        <translation>Program adı</translation>
    </message>
    <message>
        <location filename="../metadatamodel.cpp" line="98"/>
        <source>Copyright</source>
        <translation>Telif Hakkı</translation>
    </message>
    <message>
        <location filename="../metadatamodel.cpp" line="101"/>
        <source>Horizontal resolution</source>
        <translation>Yatay çözünürlük</translation>
    </message>
    <message>
        <location filename="../metadatamodel.cpp" line="103"/>
        <source>Vertical resolution</source>
        <translation>Dikey çözünürlük</translation>
    </message>
    <message>
        <location filename="../metadatamodel.cpp" line="105"/>
        <source>Resolution unit</source>
        <translation>Çözünürlük birimi</translation>
    </message>
    <message>
        <location filename="../metadatamodel.cpp" line="107"/>
        <source>Colour representation</source>
        <translation>Renk sunumu</translation>
    </message>
    <message>
        <location filename="../metadatamodel.cpp" line="110"/>
        <source>Camera maker</source>
        <translation>Kamera üreticisi</translation>
    </message>
    <message>
        <location filename="../metadatamodel.cpp" line="112"/>
        <source>Camera model</source>
        <translation>Kamera modeli</translation>
    </message>
    <message>
        <location filename="../metadatamodel.cpp" line="114"/>
        <source>F-stop</source>
        <translation>Diyafram</translation>
    </message>
    <message>
        <location filename="../metadatamodel.cpp" line="116"/>
        <source>Exposure time</source>
        <translation>Pozlama süresi</translation>
    </message>
    <message>
        <location filename="../metadatamodel.cpp" line="118"/>
        <source>ISO speed</source>
        <translation>ISO hızı</translation>
    </message>
    <message>
        <location filename="../metadatamodel.cpp" line="120"/>
        <source>Exposure bias</source>
        <translation>Pozlama sapması</translation>
    </message>
    <message>
        <location filename="../metadatamodel.cpp" line="122"/>
        <source>Focal length</source>
        <translation>Odak uzaklığı</translation>
    </message>
    <message>
        <location filename="../metadatamodel.cpp" line="124"/>
        <source>Max aperture</source>
        <translation>Azami açıklık</translation>
    </message>
    <message>
        <location filename="../metadatamodel.cpp" line="126"/>
        <source>Metering mode</source>
        <translation>Ölçme kipi</translation>
    </message>
    <message>
        <location filename="../metadatamodel.cpp" line="128"/>
        <source>Subject distance</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../metadatamodel.cpp" line="130"/>
        <source>Flash mode</source>
        <translation>Flaş kipi</translation>
    </message>
    <message>
        <location filename="../metadatamodel.cpp" line="132"/>
        <source>35mm focal length</source>
        <translation>35mm odak uzaklığı</translation>
    </message>
    <message>
        <location filename="../metadatamodel.cpp" line="135"/>
        <source>Lens model</source>
        <translation>Mercek modeli</translation>
    </message>
    <message>
        <location filename="../metadatamodel.cpp" line="137"/>
        <source>Contrast</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../metadatamodel.cpp" line="139"/>
        <source>Brightness</source>
        <translation>Parlaklık</translation>
    </message>
    <message>
        <location filename="../metadatamodel.cpp" line="141"/>
        <source>Exposure program</source>
        <translation>Pozlama programı</translation>
    </message>
    <message>
        <location filename="../metadatamodel.cpp" line="143"/>
        <source>Saturation</source>
        <translation>Doygunluk</translation>
    </message>
    <message>
        <location filename="../metadatamodel.cpp" line="145"/>
        <source>Sharpness</source>
        <translation>Keskinlik</translation>
    </message>
    <message>
        <location filename="../metadatamodel.cpp" line="147"/>
        <source>White balance</source>
        <translation>Beyaz dengesi</translation>
    </message>
    <message>
        <location filename="../metadatamodel.cpp" line="149"/>
        <source>Digital zoom</source>
        <translation>Dijital yakınlaştırma</translation>
    </message>
    <message>
        <location filename="../metadatamodel.cpp" line="151"/>
        <source>EXIF version</source>
        <translation>EXIF sürümü</translation>
    </message>
    <message>
        <location filename="../metadatamodel.cpp" line="154"/>
        <source>Latitude reference</source>
        <translation>Enlem kaynağı</translation>
    </message>
    <message>
        <location filename="../metadatamodel.cpp" line="156"/>
        <source>Latitude</source>
        <translation>Enlem</translation>
    </message>
    <message>
        <location filename="../metadatamodel.cpp" line="158"/>
        <source>Longitude reference</source>
        <translation>Boylam kaynağı</translation>
    </message>
    <message>
        <location filename="../metadatamodel.cpp" line="160"/>
        <source>Longitude</source>
        <translation>Boylam</translation>
    </message>
    <message>
        <location filename="../metadatamodel.cpp" line="162"/>
        <source>Altitude reference</source>
        <translation>Rakım kaynağı</translation>
    </message>
    <message>
        <location filename="../metadatamodel.cpp" line="164"/>
        <source>Altitude</source>
        <translation>Rakım</translation>
    </message>
    <message>
        <location filename="../metadatamodel.cpp" line="174"/>
        <source>%1 x %2</source>
        <translation>%1 x %2</translation>
    </message>
    <message>
        <location filename="../metadatamodel.cpp" line="192"/>
        <source>%1 : %2</source>
        <translation>%1 : %2</translation>
    </message>
    <message>
        <location filename="../metadatamodel.cpp" line="317"/>
        <source>Property</source>
        <translation>Özellik</translation>
    </message>
    <message>
        <location filename="../metadatamodel.cpp" line="317"/>
        <source>Value</source>
        <translation>Değer</translation>
    </message>
</context>
<context>
    <name>SettingsDialog</name>
    <message>
        <location filename="../settingsdialog.cpp" line="21"/>
        <source>Settings</source>
        <translation>Ayarlar</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="26"/>
        <source>Do nothing</source>
        <translation>Hiçbir şey yapma</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="27"/>
        <source>Close the window</source>
        <translation>Pencereyi kapat</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="28"/>
        <source>Toggle maximize</source>
        <translation>Tam boyuta geç</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="32"/>
        <source>Zoom in and out</source>
        <translation>Yaklaştır ve uzaklaştır</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="33"/>
        <source>View next or previous item</source>
        <translation>Sonraki veya önceki ögeyi görüntüle</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="37"/>
        <source>Auto size</source>
        <translation>Otomatik boyut</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="38"/>
        <source>Maximized</source>
        <translation>Tam boyut</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="56"/>
        <source>Stay on top when start-up</source>
        <translation>Açılışta pencerelerin üstünde kal</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="57"/>
        <source>Double-click behavior</source>
        <translation>Çift tıklama davranışı</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="58"/>
        <source>Mouse wheel behavior</source>
        <translation>Fare tekeri davranışı</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="59"/>
        <source>Default window size</source>
        <translation>Öntanımlı pencere boyutu</translation>
    </message>
</context>
<context>
    <name>main</name>
    <message>
        <location filename="../main.cpp" line="38"/>
        <source>Pineapple Pictures</source>
        <translation>Ananas Resimler</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="42"/>
        <source>File list.</source>
        <translation>Dosya list.</translation>
    </message>
</context>
</TS>
